@@ -1,4 +1,4 @@
-__version__ = "0.4.1"
+__version__ = "0.4.6"
 
 from importlib.util import find_spec
 
@@ -17,10 +17,12 @@ if find_spec("kedro"):
     from .extras.hooks.add_catalog_dict import *  # NOQA
     from .extras.hooks.add_transformers import *  # NOQA
     from .extras.hooks.mlflow.mlflow_basic_logger import *  # NOQA
+    from .extras.hooks.mlflow.mlflow_catalog_logger import *  # NOQA
     from .extras.hooks.mlflow.mlflow_artifacts_logger import *  # NOQA
     from .extras.hooks.mlflow.mlflow_time_logger import *  # NOQA
     from .extras.hooks.mlflow.mlflow_datasets_logger import *  # NOQA
     from .extras.hooks.mlflow.mlflow_env_vars_logger import *  # NOQA
+    from .extras.datasets.mlflow.mlflow_dataset import *  # NOQA
     from .extras.transformers.mlflow.mlflow_io_time_logger import *  # NOQA
 
 if find_spec("pandas"):
