@@ -21,14 +21,17 @@ def mlflow_log_artifacts(paths, artifact_path=None, enable_mlflow=True):
             from mlflow import log_artifact, log_artifacts
 
             for path in paths:
+                resolved_path = Path(path).resolve()
                 if Path(path).is_file():
                     log_artifact(path, artifact_path)
-                    log.info("File at '{}' was logged by MLflow.".format(path))
+                    log.info("File at '{}' was logged by MLflow.".format(resolved_path))
                 elif Path(path).is_dir():
                     log_artifacts(path, artifact_path)
-                    log.info("Directory at '{}' was logged by MLflow.".format(path))
+                    log.info(
+                        "Directory at '{}' was logged by MLflow.".format(resolved_path)
+                    )
                 else:
-                    log.warning("'{}' was not found.".format(path))
+                    log.warning("Path '{}' does not exist.".format(resolved_path))
         except Exception:
             log.warning(
                 "{} failed to be logged by MLflow.".format(paths), exc_info=True
@@ -40,7 +43,11 @@ def mlflow_log_metrics(metrics, step=None, enable_mlflow=True):
 
     if enable_mlflow:
         try:
-            metrics = {k.replace(":", ".."): float(v) for (k, v) in metrics.items()}
+            metrics = {
+                k.replace(":", ".."): float(v)
+                for (k, v) in metrics.items()
+                if isinstance(v, (float, int))
+            }
 
             from mlflow import log_metrics
 
@@ -57,8 +64,9 @@ def mlflow_log_params(params, enable_mlflow=True):
     if enable_mlflow:
         try:
             params = {
-                k.replace(":", ".."): ("{}".format(v)[:250] if v else "")
+                k.replace(":", ".."): ("{}".format(v)[:250])
                 for (k, v) in params.items()
+                if isinstance(v, str) or v
             }
 
             from mlflow import log_params
