@@ -59,7 +59,11 @@ class HatchDict:
         # type: (...) -> Any
 
         assert (key is None) or (
-            key.__class__.__name__ in {"str", "int",}
+            key.__class__.__name__
+            in {
+                "str",
+                "int",
+            }
         ), "Received key: {}".format(key)
         assert lookup.__class__.__name__ in {"dict"}, "Received lookup: s{}".format(
             lookup
@@ -321,13 +325,13 @@ https://github.com/quantumblacklabs/kedro/blob/0.15.4/kedro/utils.py
 
 def load_obj(obj_path: str, default_obj_path: str = "") -> Any:
     """Extract an object from a given path.
-        Args:
-            obj_path: Path to an object to be extracted, including the object name.
-            default_obj_path: Default object path.
-        Returns:
-            Extracted object.
-        Raises:
-            AttributeError: When the object does not have the given named attribute.
+    Args:
+        obj_path: Path to an object to be extracted, including the object name.
+        default_obj_path: Default object path.
+    Returns:
+        Extracted object.
+    Raises:
+        AttributeError: When the object does not have the given named attribute.
     """
     obj_path_list = obj_path.rsplit(".", 1)
     obj_path = obj_path_list.pop(0) if len(obj_path_list) > 1 else default_obj_path
